@@ -1,4 +1,4 @@
-/* $Id: cxp-utils.h,v 1.6 2005/04/16 15:15:19 yasumichi Exp $ */
+/* $Id: cxp-utils.h,v 1.9 2005/05/18 16:40:45 yasumichi Exp $ */
 /**
  * \if japanese
  * @file
@@ -6,7 +6,7 @@
  *
  * @author 
  * @date Fri Jan 21 2005
- * $Revision: 1.6 $
+ * $Revision: 1.9 $
  * \endif
  * \if english
  * @file
@@ -14,7 +14,7 @@
  *
  * @author Yasumichi Akahoshi
  * @date Fri Jan 21 2005
- * $Revision: 1.6 $
+ * $Revision: 1.9 $
  * \endif
  */
 
@@ -54,6 +54,9 @@ void cxp_utils_free_filename_filter (void);
 gchar *cxp_path_get_basename_of_utf8 (const gchar * file_name);
 gchar *cxp_path_get_dirname_of_utf8 (const gchar * file_name);
 gchar *cxp_strftime (const time_t * timep);
+void *cxp_error_dialog_run_about_file (gchar *filename);
+gboolean cxp_remove_file (const gchar *fullpath);
+gchar* cxp_utils_make_unique_key (void);
 
 #ifdef __cplusplus
 }
