@@ -1,4 +1,4 @@
-/* $Id: cxp-handler.c,v 1.12 2005/04/18 13:51:47 yasumichi Exp $ */
+/* $Id: cxp-handler.c,v 1.13 2005/04/21 16:16:47 yasumichi Exp $ */
 /**
  * \if japanese
  * @file
@@ -6,7 +6,7 @@
  *
  * @author 
  * @date Tue Mar 29 2005
- * $Revision: 1.12 $
+ * $Revision: 1.13 $
  * \endif
  * \if english
  * @file
@@ -14,7 +14,7 @@
  *
  * @author Yasumichi Akahoshi
  * @date Tue Mar 29 2005
- * $Revision: 1.12 $
+ * $Revision: 1.13 $
  * \endif
  */
 
@@ -40,6 +40,7 @@
 
 #include <glib/gi18n-lib.h>
 #include <string.h>
+#include "cxp-utils.h"
 #include "cxp-profile.h"
 #include "cxp-handler.h"
 #include "cxp-entry-dialog.h"
@@ -260,7 +261,7 @@ void cxp_handler_launch (CxpHandler * handler, const gchar * fullpath)
 
 	g_return_if_fail (fullpath != NULL);
 
-	filename = g_path_get_basename (fullpath);
+	filename = cxp_path_get_basename_of_utf8 (fullpath);
 	if ((suffix = g_strrstr (filename, ".")) != NULL)
 	{
 		cmd = cxp_profile_get_string (priv->profile, suffix);
